Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-03-02 20:05:54 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-03-02 20:05:54 +0400
commit7bbf4b78313df9f6d2c760b527eb36a5d0418b82 (patch)
treeace55a086362cf5b35174d55442322a793dd32c1 /source/blender/blenkernel/BKE_mesh.h
parentc8636ca3dd8bde1cc548ef21fb7a1fd304799164 (diff)
style cleanup
- spelling - turns out we had tessellation spelt wrong all over. - use \directive for doxy (not @directive) - remove BLI_sparsemap.h - was from bmesh merge IIRC but entire file commented and not used.
Diffstat (limited to 'source/blender/blenkernel/BKE_mesh.h')
-rw-r--r--source/blender/blenkernel/BKE_mesh.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenkernel/BKE_mesh.h b/source/blender/blenkernel/BKE_mesh.h
index 6c6153523b7..4a37252e3fb 100644
--- a/source/blender/blenkernel/BKE_mesh.h
+++ b/source/blender/blenkernel/BKE_mesh.h
@@ -64,19 +64,19 @@ extern "C" {
struct BMesh *BKE_mesh_to_bmesh(struct Mesh *me, struct Object *ob);
/*
* this function recreates a tesselation.
* returns number of tesselation faces.
*
* use_poly_origindex sets whether or not the tesselation faces' origindex
* layer should point to original poly indices or real poly indices.
*
* use_face_origindex sets the tesselation faces' origindex layer
* to point to the tesselation faces themselves, not the polys.
*
* if both of the above are 0, it'll use the indices of the mpolys of the MPoly
* data in pdata, and ignore the origindex layer altogether.
*/
-int mesh_recalcTesselation(struct CustomData *fdata, struct CustomData *ldata, struct CustomData *pdata,
+int mesh_recalcTessellation(struct CustomData *fdata, struct CustomData *ldata, struct CustomData *pdata,
struct MVert *mvert,
int totface, int totloop, int totpoly,
const int do_face_normals);
@@ -198,7 +198,7 @@ typedef struct UvMapVert {
/* UvElement stores per uv information so that we can quickly access information for a uv.
* it is actually an improved UvMapVert, including an island and a direct pointer to the face
- * to avoid initialising face arrays */
+ * to avoid initializing face arrays */
typedef struct UvElement {
/* Next UvElement corresponding to same vertex */
struct UvElement *next;
@@ -64,19 +64,19 @@ extern "C" {
struct BMesh *BKE_mesh_to_bmesh(struct Mesh *me, struct Object *ob);
/*
- * this function recreates a tesselation.
- * returns number of tesselation faces.
+ * this function recreates a tessellation.
+ * returns number of tessellation faces.
*
@@ -64,19 +64,19 @@ extern "C" {
*
- * use_poly_origindex sets whether or not the tesselation faces' origindex
+ * use_poly_origindex sets whether or not the tessellation faces' origindex
* layer should point to original poly indices or real poly indices.
*
@@ -64,19 +64,19 @@ extern "C" {
* layer should point to original poly indices or real poly indices.
*
- * use_face_origindex sets the tesselation faces' origindex layer
- * to point to the tesselation faces themselves, not the polys.
+ * use_face_origindex sets the tessellation faces' origindex layer
+ * to point to the tessellation faces themselves, not the polys.
*
* if both of the above are 0, it'll use the indices of the mpolys of the MPoly